Crate holochain_p2p

Crate holochain_p2p 

holochain specific wrapper around more generic p2p module

Modules

__mock_MockHolochainP2pDnaT
__mock_MockHolochainP2pDnaT_HolochainP2pDnaT
actor
Module containing the HolochainP2p actor definition.
event
Module containing incoming events from HolochainP2p.

Structs

HcReportConfig
Configuration parameters for HcReportFactory.
HcReportFactory
Holochain report module. See module level docs for details.
HcReportModConfig
Module-level configuration for HcReport.
HolochainBlocks
Block implementation in Holochain.
HolochainBlocksFactory
Factory for constructing kitsune2_api Blocks backed by the conductor DB. Uses GetDbConductor to query and persist block state (agents, DNAs, cells, spaces), enabling enforcement of block rules across a SpaceId via the BlocksFactory trait.
HolochainOpStore
Holochain implementation of the Kitsune2 OpStore.
HolochainOpStoreFactory
Holochain implementation of the Kitsune2 OpStoreFactory.
HolochainP2pConfig
HolochainP2p config struct.
HolochainP2pDna
A wrapper around HolochainP2pSender that partially applies the dna_hash / agent_pub_key. I.e. a sender that is tied to a specific cell.
HolochainP2pLocalAgent
Holochain implementation of a Kitsune2 LocalAgent and Signer.
HolochainPeerMetaStore
Holochain implementation of a Kitsune2 PeerMetaStore.
HolochainPeerMetaStoreFactory
Holochain implementation of the Kitsune2 kitsune2_api::OpStoreFactory.
MockHolochainP2pDnaT
A wrapper around HolochainP2pSender that partially applies the dna_hash / agent_pub_key. I.e. a sender that is tied to a specific cell.
NetworkCompatParams
Some parameters used as part of a protocol compatibility check during tx5 preflight
WireDhtOpData
Struct for encoding DhtOp as bytes.
WrapEvtSender
Evt wrapper to allow timing traces.

Enums

HolochainP2pError
Error type for Holochain P2p.
ReportConfig
Configure reporting.
WireMessage

Constants

HCP2P_PROTO_VER
See NetworkCompatParams::proto_ver.

Traits

HolochainP2pDnaT
A wrapper around HolochainP2pSender that partially applies the dna_hash / agent_pub_key. I.e. a sender that is tied to a specific cell.

Functions

spawn_holochain_p2p
Spawn a new HolochainP2p actor. Conductor will call this on initialization.

Type Aliases

DynHolochainP2pDna
Trait object for HolochainP2pDnaT.
GetDbConductor
Callback function to retrieve a conductor database.
GetDbOpStore
Callback function to retrieve a op store database handle for a dna hash.
GetDbPeerMeta
Callback function to retrieve a peer meta database handle for a dna hash.
HolochainP2pResult
Holochain p2p result type.