holochain specific wrapper around more generic p2p module
Modules
- __
mock_ Mock Holochain P2pDnaT - __
mock_ Mock Holochain P2pDnaT_ Holochain P2pDnaT - actor
- Module containing the HolochainP2p actor definition.
- event
- Module containing incoming events from HolochainP2p.
Structs
- HcReport
Config - Configuration parameters for HcReportFactory.
- HcReport
Factory - Holochain report module. See module level docs for details.
- HcReport
ModConfig - Module-level configuration for HcReport.
- Holochain
Blocks - Block implementation in Holochain.
- Holochain
Blocks Factory - Factory for constructing kitsune2_api Blocks backed by the conductor DB. Uses GetDbConductor to query and persist block state (agents, DNAs, cells, spaces), enabling enforcement of block rules across a SpaceId via the BlocksFactory trait.
- Holochain
OpStore - Holochain implementation of the Kitsune2 OpStore.
- Holochain
OpStore Factory - Holochain implementation of the Kitsune2 OpStoreFactory.
- Holochain
P2pConfig - HolochainP2p config struct.
- Holochain
P2pDna - A wrapper around HolochainP2pSender that partially applies the dna_hash / agent_pub_key. I.e. a sender that is tied to a specific cell.
- Holochain
P2pLocal Agent - Holochain implementation of a Kitsune2 LocalAgent and Signer.
- Holochain
Peer Meta Store - Holochain implementation of a Kitsune2 PeerMetaStore.
- Holochain
Peer Meta Store Factory - Holochain implementation of the Kitsune2 kitsune2_api::OpStoreFactory.
- Mock
Holochain P2pDnaT - A wrapper around HolochainP2pSender that partially applies the dna_hash / agent_pub_key. I.e. a sender that is tied to a specific cell.
- Network
Compat Params - Some parameters used as part of a protocol compatibility check during tx5 preflight
- Wire
DhtOp Data - Struct for encoding DhtOp as bytes.
- Wrap
EvtSender - Evt wrapper to allow timing traces.
Enums
- Holochain
P2pError - Error type for Holochain P2p.
- Report
Config - Configure reporting.
- Wire
Message
Constants
Traits
- Holochain
P2pDnaT - A wrapper around HolochainP2pSender that partially applies the dna_hash / agent_pub_key. I.e. a sender that is tied to a specific cell.
Functions
- spawn_
holochain_ p2p - Spawn a new HolochainP2p actor. Conductor will call this on initialization.
Type Aliases
- DynHolochain
P2pDna - Trait object for HolochainP2pDnaT.
- GetDb
Conductor - Callback function to retrieve a conductor database.
- GetDb
OpStore - Callback function to retrieve a op store database handle for a dna hash.
- GetDb
Peer Meta - Callback function to retrieve a peer meta database handle for a dna hash.
- Holochain
P2pResult - Holochain p2p result type.